@@ -1326,60 +1326,64 @@ gdl_dock_item_dock (GdlDockObject    *object,
     if (parent)
         gdl_dock_object_freeze (parent);
 
-    /* ref ourselves since we could be destroyed when detached */
+    
     if (new_parent)
     {
+        /* ref ourselves since we could be destroyed when detached */ 
         g_object_ref (object);
         GDL_DOCK_OBJECT_SET_FLAGS (object, GDL_DOCK_IN_REFLOW);
         gdl_dock_object_detach (object, FALSE);
-    }
 
-    /* freeze the new parent, so reduce won't get called before it's
-       actually added to our parent */
-    gdl_dock_object_freeze (new_parent);
+        /* freeze the new parent, so reduce won't get called before it's
+           actually added to our parent */
+        gdl_dock_object_freeze (new_parent);
     
-    /* bind the new parent to our master, so the following adds work */
-    gdl_dock_object_bind (new_parent, G_OBJECT (GDL_DOCK_OBJECT_GET_MASTER (object)));
+        /* bind the new parent to our master, so the following adds work */
+        gdl_dock_object_bind (new_parent, G_OBJECT (GDL_DOCK_OBJECT_GET_MASTER (object)));
     
-    /* add the objects */
-    if (add_ourselves_first) {
-        gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (object));
-        gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (requestor));
-        splitpos = available_space - pref_size;
-    } else {
-        gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (requestor));
-        gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (object));
-        splitpos = pref_size;
-    }
+        /* add the objects */
+        if (add_ourselves_first) {
+            gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (object));
+            gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (requestor));
+            splitpos = available_space - pref_size;
+        } else {
+            gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (requestor));
+            gtk_container_add (GTK_CONTAINER (new_parent), GTK_WIDGET (object));
+            splitpos = pref_size;
+        }
 
-    /* add the new parent to the parent */
-    if (parent)
-        gtk_container_add (GTK_CONTAINER (parent), GTK_WIDGET (new_parent));
+        /* add the new parent to the parent */
+        if (parent)
+            gtk_container_add (GTK_CONTAINER (parent), GTK_WIDGET (new_parent));
 
-    /* show automatic object */
-    if (GTK_WIDGET_VISIBLE (object))
-    {
-        gtk_widget_show (GTK_WIDGET (new_parent));
-        GDL_DOCK_OBJECT_UNSET_FLAGS (object, GDL_DOCK_IN_REFLOW);
+        /* show automatic object */
+        if (GTK_WIDGET_VISIBLE (object))
+        {
+            gtk_widget_show (GTK_WIDGET (new_parent));
+            GDL_DOCK_OBJECT_UNSET_FLAGS (object, GDL_DOCK_IN_REFLOW);
+        }
         gdl_dock_object_thaw (new_parent);
-    }
-    else // If the parent is already a DockNotebook, we don't need
-  	                                 // to create a new one.
-        gtk_container_add (GTK_CONTAINER (parent), GTK_WIDGET (requestor));
-    
-    /* use extra docking parameter */
-    if (position != GDL_DOCK_CENTER && other_data &&
-        G_VALUE_HOLDS (other_data, G_TYPE_UINT)) {
-        
-        g_object_set (G_OBJECT (new_parent),
-                      "position", g_value_get_uint (other_data),
-                      NULL);
-    } else if (splitpos > 0 && splitpos < available_space) {
-        g_object_set (G_OBJECT (new_parent), "position", splitpos, NULL);
-    }
-    
-    g_object_unref (object);
 
+        /* use extra docking parameter */
+        if (position != GDL_DOCK_CENTER && other_data &&
+            G_VALUE_HOLDS (other_data, G_TYPE_UINT)) {
+        
+            g_object_set (G_OBJECT (new_parent),
+                          "position", g_value_get_uint (other_data),
+                          NULL);
+        } else if (splitpos > 0 && splitpos < available_space) {
+            g_object_set (G_OBJECT (new_parent), "position", splitpos, NULL);
+        }
+    
+        g_object_unref (object);
+    }
+    else
+    {
+        /* If the parent is already a DockNotebook, we don't need
+         to create a new one. */
+        gtk_container_add (GTK_CONTAINER (parent), GTK_WIDGET (requestor));
+    }
+    
     requestor_parent = gdl_dock_object_get_parent_object (requestor);
     if (GDL_IS_DOCK_NOTEBOOK (requestor_parent))
     {
@@ -2026,6 +2030,15 @@ gdl_dock_item_unlock (GdlDockItem *item)
     g_object_set (item, "locked", FALSE, NULL);
 }
 
+/**
+ * gdl_dock_item_set_default_position:
+ * @item: The dock item
+ * @reference: The GdlDockObject which is the default dock for @item 
+ *
+ * This method has only an effect when you add you dock_item with
+ * GDL_DOCK_ITEM_BEH_NEVER_FLOATING. In this case you have to assign
+ * it a default position.
+ **/
 void 
 gdl_dock_item_set_default_position (GdlDockItem   *item,
                                     GdlDockObject *reference)
